# probabilistic-rule-engine

## Getting Started
Install poetry: https://python-poetry.org/docs/#installation

## Configure credentials
You'll need to ask Dmitry for the `PYPI_API_TOKEN`.
`poetry config pypi-token.pypi $PYPI_API_TOKEN`

## Package
`poetry build`

## Publish
`poetry publish`